@@ -31,7 +31,7 @@ pub fn extract_symbol(
         "huobi" => exchanges::huobi::extract_symbol(market_type, msg),
         "kraken" => exchanges::kraken::extract_symbol(market_type, msg),
         "kucoin" => exchanges::kucoin::extract_symbol(market_type, msg),
-        "mxc" => exchanges::mxc::extract_symbol(market_type, msg),
+        "mxc" | "mexc" => exchanges::mexc::extract_symbol(market_type, msg),
         "okex" => exchanges::okex::extract_symbol(market_type, msg),
         "okx" => exchanges::okx::extract_symbol(market_type, msg),
         "zbg" => exchanges::zbg::extract_symbol(market_type, msg),
@@ -62,7 +62,7 @@ pub fn parse_trade(
         "huobi" => exchanges::huobi::parse_trade(market_type, msg),
         "kraken" => exchanges::kraken::parse_trade(market_type, msg),
         "kucoin" => exchanges::kucoin::parse_trade(market_type, msg),
-        "mxc" => exchanges::mxc::parse_trade(market_type, msg),
+        "mxc" | "mexc" => exchanges::mexc::parse_trade(market_type, msg),
         "okex" => exchanges::okex::parse_trade(market_type, msg),
         "okx" => exchanges::okx::parse_trade(market_type, msg),
         "zbg" => exchanges::zbg::parse_trade(market_type, msg),
@@ -106,7 +106,7 @@ pub fn parse_l2(
         "huobi" => exchanges::huobi::parse_l2(market_type, msg),
         "kraken" => exchanges::kraken::parse_l2(market_type, msg),
         "kucoin" => exchanges::kucoin::parse_l2(market_type, msg, timestamp),
-        "mxc" => exchanges::mxc::parse_l2(market_type, msg, timestamp),
+        "mxc" | "mexc" => exchanges::mexc::parse_l2(market_type, msg, timestamp),
         "okex" => exchanges::okex::parse_l2(market_type, msg),
         "okx" => exchanges::okx::parse_l2(market_type, msg),
         "zbg" => exchanges::zbg::parse_l2(market_type, msg),
